nctl add cluster
nctl add cluster
Add cluster
nctl add cluster [flags]
Examples
# Add a cluster with a specified name and onboarding token
nctl add cluster --cluster-name my-cluster --onboarding-token abc123xyz
# Add a cluster using a values file for onboarding parameters
nctl add cluster -f /path/to/values.yaml
# Specify a custom Helm repository and release name
nctl add cluster --helm-repo https://custom.repo.com/helm-charts -r custom-release
# Use a private Helm repository with authentication
nctl add cluster --helm-repo https://private.repo.com/helm-charts -t my-private-repo-token
# Register a cluster without installing the operator
nctl add cluster --cluster-name my-cluster --register-only
# Deploy Kyverno with a specific version in a custom namespace
nctl add cluster --kyverno-version 1.12 -n custom-namespace
# Use a custom Kubeconfig file and context for the cluster
nctl add cluster --kubeconfig /path/to/kubeconfig --kube-context my-context
# Specify a private container registry
nctl add cluster --registry-name my-private-registry --registry-username myuser --registry-password mypassword
# Allow connections to an address with a self-signed or unverified certificate (not recommended)
nctl add cluster --insecure
```bash
### Options
```text
--cluster-name string name of the cluster to onboard is required (not needed if onboarding token is provided)
-t, --git-token string token for the operator helm chart in private helm repo
--helm-repo string operator helm repository name (default "https://nirmata.github.io/kyverno-charts")
-h, --help help for cluster
--insecure allow connection to a Nirmata server with a insecure certificate (not recommended)
--kube-context string the kube context from configured kubeconfig. Default is the current or sole context
--kubeconfig string kubeconfig path (defaults to $HOME/.kube/kubeconfig)
--kyverno-version string Kyverno version 1.11 (default "1.11")
-n, --namespace string operator namespace (default "nirmata-system")
--npm-only npm only mode for the operator
--onboarding-token string the cluster onboarding token
--register-only only register cluster, don't install operator
--registry-name string name of the private registry (no need if images are not pushed to private registry)
--registry-password string password of the private registry (no need if images are not pushed to private registry)
--registry-username string user name of the private registry (no need if images are not pushed to private registry)
-r, --release string operator helm chart release name (default "kyverno-operator")
--token string the Nirmata API Login Key (env NIRMATA_TOKEN)
--url string the Nirmata server base URL (env NIRMATA_URL)
-f, --values-file string the cluster onboarding parameter YAML file
--yes bypass manual validation
```text
### Options inherited from parent commands
```text
-v, --v Level number for the log level verbosity
SEE ALSO
- nctl add - Add resources to Nirmata Control Hub
Feedback
Was this page helpful?
Glad to hear it! Please tell us how we can improve.
Sorry to hear that. Please tell us how we can improve.